@@ -250,6 +250,11 @@ class InstanceCode(Code):
 
         self.many_to_many_waiting_list = {}
         for field in self.model._meta.many_to_many:
+            try:
+                if not field.remote_field.through._meta.auto_created:
+                    continue
+            except AttributeError:
+                pass
             self.many_to_many_waiting_list[field] = list(getattr(self.instance, field.name).all())
 
     def get_lines(self, force=False):
@@ -406,12 +411,10 @@ class Script(Code):
             This isn't essential, but makes the script look nicer because
             more instances can be defined on their first try.
         """
-
-        # Max number of cycles allowed before we call it an infinite loop.
-        MAX_CYCLES = 5
-
         model_queue = []
         number_remaining_models = len(models)
+        # Max number of cycles allowed before we call it an infinite loop.
+        MAX_CYCLES = number_remaining_models
         allowed_cycles = MAX_CYCLES
 
         while number_remaining_models > 0:
@@ -665,9 +668,7 @@ def get_attribute_value(item, field, context, force=False, skip_autofield=True):
         # content types in this script, as they can be generated again
         # automatically.
         # NB: Not sure if "is" will always work
-        remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel  # Remove me after Django 1.8 is unsupported
-        remote_field_model = remote_field.model if hasattr(remote_field, 'model') else remote_field.to  # Remove me after Django 1.8 is unsupported
-        if remote_field_model is ContentType:
+        if field.remote_field.model is ContentType:
             return 'ContentType.objects.get(app_label="%s", model="%s")' % (value.app_label, value.model)
 
         # Generate an identifier (key) for this foreign object
@@ -714,21 +715,17 @@ def check_dependencies(model, model_queue, avaliable_models):
     # For each ForeignKey or ManyToMany field, check that a link is possible
 
     for field in model._meta.fields:
-        remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel  # Remove me after Django 1.8 is unsupported
-        if not remote_field:
+        if not field.remote_field:
             continue
-        remote_field_model = remote_field.model if hasattr(remote_field, 'model') else remote_field.to  # Remove me after Django 1.8 is unsupported
-        if remote_field_model.__name__ not in allowed_links:
-            if remote_field_model not in avaliable_models:
+        if field.remote_field.model.__name__ not in allowed_links:
+            if field.remote_field.model not in avaliable_models:
                 continue
             return False
 
     for field in model._meta.many_to_many:
-        remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel  # Remove me after Django 1.8 is unsupported
-        if not remote_field:
+        if not field.remote_field:
             continue
-        remote_field_model = remote_field.model if hasattr(remote_field, 'model') else remote_field.to  # Remove me after Django 1.8 is unsupported
-        if remote_field_model.__name__ not in allowed_links:
+        if field.remote_field.model.__name__ not in allowed_links:
             return False
 
     return True
